@@ -13,13 +13,18 @@
 #' need to be emphasized.
 #' @param monospace A T/F value to control whether the text of the selected column
 #' need to be monospaced (verbatim)
+#' @param color A character string for column text color. Here please pay
+#' attention to the differences in color codes between HTML and LaTeX.
+#' @param background A character string for column background color. Here please
+#' pay attention to the differences in color codes between HTML and LaTeX.
 #'
 #' @examples x <- knitr::kable(head(mtcars), "html")
 #' row_spec(x, 1, bold = TRUE, italic = TRUE)
 #'
 #' @export
 row_spec <- function(kable_input, row,
-                     bold = FALSE, italic = FALSE, monospace = FALSE) {
+                     bold = FALSE, italic = FALSE, monospace = FALSE,
+                     color = NULL, background = NULL) {
   if (!is.numeric(row)) {
     stop("row must be a numeric value")
   }
@@ -29,14 +34,17 @@ row_spec <- function(kable_input, row,
     return(kable_input)
   }
   if (kable_format == "html") {
-    return(row_spec_html(kable_input, row, bold, italic, monospace))
+    return(row_spec_html(kable_input, row, bold, italic, monospace,
+                         color, background))
   }
   if (kable_format == "latex") {
-    return(row_spec_latex(kable_input, row, bold, italic, monospace))
+    return(row_spec_latex(kable_input, row, bold, italic, monospace,
+                          color, background))
   }
 }
 
-row_spec_html <- function(kable_input, row, bold, italic, monospace) {
+row_spec_html <- function(kable_input, row, bold, italic, monospace,
+                          color, background) {
   kable_attrs <- attributes(kable_input)
   kable_xml <- read_kable_as_xml(kable_input)
   kable_tbody <- xml_tpart(kable_xml, "tbody")
@@ -63,13 +71,23 @@ row_spec_html <- function(kable_input, row, bold, italic, monospace) {
       xml_attr(target_cell, "style") <- paste0(xml_attr(target_cell, "style"),
                                                "font-family: monospace;")
     }
+    if (!is.null(color)) {
+      xml_attr(target_cell, "style") <- paste0(xml_attr(target_cell, "style"),
+                                               "color: ", color, ";")
+    }
+    if (!is.null(background)) {
+      xml_attr(target_cell, "style") <- paste0(xml_attr(target_cell, "style"),
+                                               "background-color: ",
+                                               background, ";")
+    }
   }
   out <- as_kable_xml(kable_xml)
   attributes(out) <- kable_attrs
   return(out)
 }
 
-row_spec_latex <- function(kable_input, row, bold, italic, monospace) {
+row_spec_latex <- function(kable_input, row, bold, italic, monospace,
+                           color, background) {
   table_info <- magic_mirror(kable_input)
   target_row <- table_info$contents[row + 1]
   new_row <- latex_row_cells(target_row)
@@ -88,9 +106,20 @@ row_spec_latex <- function(kable_input, row, bold, italic, monospace) {
       paste0("\\\\ttfamily{", x, "}")
     })
   }
+
+  if (!is.null(color)) {
+    new_row <- lapply(new_row, function(x) {
+      paste0("\\\\textcolor{", color, "}{", x, "}")
+    })
+  }
   new_row <- paste(unlist(new_row), collapse = " & ")
 
-  out <- sub(target_row, new_row, as.character(kable_input), perl = T)
+  if (!is.null(background)) {
+    new_row <- paste0("\\\\rowcolor{", background, "}  ", new_row)
+  }
+
+  out <- sub(target_row, new_row, enc2utf8(as.character(kable_input)),
+             perl = T)
   out <- structure(out, format = "latex", class = "knitr_kable")
   attr(out, "kable_meta") <- table_info
   return(out)
