@@ -55,11 +55,12 @@ regex_escape <- function(x, double_backslash = FALSE) {
   x <- gsub("\\$", "\\\\\\$", x)
   x <- gsub("\\(", "\\\\(", x)
   x <- gsub("\\)", "\\\\)", x)
-  x <- gsub("\\[", "\\\\]", x)
-  x <- gsub("\\[", "\\\\]", x)
+  x <- gsub("\\[", "\\\\[", x)
+  x <- gsub("\\]", "\\\\]", x)
   x <- gsub("\\{", "\\\\{", x)
   x <- gsub("\\}", "\\\\}", x)
   x <- gsub("\\*", "\\\\*", x)
+  x <- gsub("\\+", "\\\\+", x)
   return(x)
 }
 
